@@ -1,3 +1,4 @@
+#include <config.h>
 #include "ev-jobs.h"
 #include "ev-job-queue.h"
 #include "ev-document-thumbnails.h"
@@ -15,9 +16,6 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <unistd.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
 
 static void ev_job_init                 (EvJob               *job);
 static void ev_job_class_init           (EvJobClass          *class);
@@ -405,8 +403,8 @@ ev_job_render_run (EvJobRender *job)
 								   job->rc->page);
 		if (job->include_images && EV_IS_DOCUMENT_IMAGES (EV_JOB (job)->document))
 			job->image_mapping =
-				ev_document_images_get_images (EV_DOCUMENT_IMAGES (EV_JOB (job)->document),
-							       job->rc->page);
+				ev_document_images_get_image_mapping (EV_DOCUMENT_IMAGES (EV_JOB (job)->document),
+								      job->rc->page);
 		EV_JOB (job)->finished = TRUE;
 	}
 
@@ -499,6 +497,11 @@ ev_job_load_dispose (GObject *object)
 		job->dest = NULL;
 	}
 
+	if (job->search_string) {
+		g_free (job->search_string);
+		job->search_string = NULL;
+	}
+
 	(* G_OBJECT_CLASS (ev_job_load_parent_class)->dispose) (object);
 }
 
@@ -514,7 +517,10 @@ ev_job_load_class_init (EvJobLoadClass *class)
 
 
 EvJob *
-ev_job_load_new (const gchar *uri, EvLinkDest *dest, EvWindowRunMode mode)
+ev_job_load_new (const gchar    *uri,
+		 EvLinkDest     *dest,
+		 EvWindowRunMode mode,
+		 const gchar    *search_string)
 {
 	EvJobLoad *job;
 
@@ -525,6 +531,8 @@ ev_job_load_new (const gchar *uri, EvLinkDest *dest, EvWindowRunMode mode)
 		job->dest = g_object_ref (dest);
 
 	job->mode = mode;
+	if (search_string)
+		job->search_string = g_strdup (search_string);
 
 	return EV_JOB (job);
 }
@@ -735,7 +743,7 @@ ev_job_print_new (EvDocument    *document,
 
 	job->page_set = page_set;
 
-	job->pages_per_sheet = pages_per_sheet;
+	job->pages_per_sheet = CLAMP (pages_per_sheet, 1, 16);
 	
 	job->copies = copies;
 	job->collate = collate;
